"nbdkit [-D|--debug PLUGIN|FILTER.FLAG=N]\n"
"       [-e|--exportname EXPORTNAME] [--exit-with-parent]\n"
"       [--filter FILTER ...] [-f|--foreground]\n"
"       [-g|--group GROUP] [-i|--ipaddr IPADDR]\n"
"       [--log stderr|syslog]\n"
"       [-n|--newstyle] [-o|--oldstyle]\n"
"       [-P|--pidfile PIDFILE]\n"
"       [-p|--port PORT] [-r|--readonly]\n"
"       [--run CMD] [-s|--single] [--selinux-label LABEL]\n"
"       [-t|--threads THREADS]\n"
"       [--tls off|on|require]\n"
"       [--tls-certificates /path/to/certificates]\n"
"       [--tls-psk /path/to/pskfile] [--tls-verify-peer]\n"
"       [-U|--unix SOCKET] [-u|--user USER]\n"
"       [-v|--verbose] [-V|--version]\n"
"       PLUGIN [[KEY=]VALUE [KEY=VALUE [...]]]\n"
"\n"
"nbdkit --dump-config\n"
"\n"
"nbdkit PLUGIN --dump-plugin\n"
"\n"
"nbdkit --help\n"
